This dataset include data on infringement decisions. There is one observation per decision per case (2002-2020). The dataset includes information on the department responsible for the decision and the member state that the decision is against.
1 |
A data frame with 34 variables:
numeric. An ID number that uniquely identifies each
observation in the dataset.
numeric. An ID number that uniquely identifies
each decision in an infringement case.
string. An ID number that uniquely identifies each
case.
numeric. The number of the case.
numeric. The year of the case.
date. The date that the Commission issued the
decision in the format YYYY-MM-DD.
numeric. The year that the Commission issued
the decision.
numeric. The month that the Commission issued
the decision.
numeric. The day that the Commission issued the
decision.
numeric. An ID number that uniquely
identifies each member state. This ID number is assigned when member states
are sorted by accession date and then alphabetically.
string. The name of the member state that the
Commission opened the case against.
string. A two letter code assigned by the
Commission that uniquely identifies each member state.
numeric. An ID number that uniquely identifies
each Commission department.
string. The name of the Commission department that
opened the infringement case.
string. A multi-letter code assigned by the
Commission that uniquely identifies each department.
numeric. An ID number that uniquely identifies
each type of state aid cases. Coded 1 for noncommunication cases,
which are cases that relate to a member state failing to notify the
Commission that it has transposed a directive by the stated deadline. Coded
2 for nonconformity cases, which are cases that relate to a member
state incorrectly transposing a directive.
string. The type of the infringement case. There
are two types of cases. Coded noncommunication for cases that relate
to a member state failing to notify the Commission that it has transposed a
directive by the stated deadline. Coded nonconformity for cases that
relate to a member state incorrectly transposing a directive.
dummy. A dummy variable indicating whether
the infringement case is a noncommunication case, which is a case that
relates to a member state failing to notify that Commission that it has
transposed a directive by the stated deadline.
dummy. A dummy variable indicating whether the
infringement case is a nonconformity case, which is a case that relates to
a member state incorrectly transposing a directive.
dummy. A dummy variable indicating whether the
description of the infringement case provided by the Commission references
a directive that the case relates to. Directive numbers have the format
####/####, where the first set of numbers is the year the directive
was enacted and the second set is the number of the directive.
string. The number of the directive that the
infringement case relates to, if applicable. Coded NA if the
description of the case provided by the Commission does not reference a
specific directive number.
string. The CELEX number of the directive that the
infringement case relates to, if applicable. Coded NA if the
description of the case provided by the Commission does not reference a
specific directive number. CELEX numbers for directives have the format
3####L####, where the first set of numbers is the year the directive
was enacted and the second set is the number of the directive.
numeric. An ID number that uniquely
identifies each decision stage in the infringement procedure. Coded
1 for letters of formal notice under Article 258 of the Treaty on
the Functioning of the European Union (TFEU), coded 2 for reasoned
opinions under Article 258, coded 3 for referrals to the Court of
Justice of the European Union (CJEU) under Article 258, coded 4 for
letters of formal notice under Article 260, coded 5 for reasoned
opinions under Article 260, and coded 6 for referrals to the Court
under Article 260.
string. The decision stage of the infringement
procedure. Possible values include: Letter of formal notice (Article
258), Reasoned opinion (Article 259), Referral to the Court
(Article 258), Letter of formal notice (Article 260),
Reasoned opinion (Article 260), and Referral to the Court
(Article 260).
dummy. A dummy variable indicating whether the
decision is a letter of formal notice sent by the Commission under Article
258 of the Treaty on the Functioning of the European Union (TFEU).
dummy. A dummy variable indicating whether the
decision is a reasoned opinion sent by the Commission under Article 258 of
the Treaty on the Functioning of the European Union (TFEU).
dummy. A dummy variable indicating whether the
decision is a referral to the Court of Justice of the European Union (CJEU)
made by the Commission under Article 258 of the Treaty on the Functioning
of the European Union (TFEU).
dummy. A dummy variable indicating whether the
decision is a letter of formal notice sent by the Commission under Article
260 of the Treaty on the Functioning of the European Union (TFEU).
dummy. A dummy variable indicating whether the
decision is a reasoned opinion sent by the Commission under Article 260 of
the Treaty on the Functioning of the European Union (TFEU).
dummy. A dummy variable indicating whether the
decision is a referral to the Court of Justice of the European Union (CJEU)
made by the Commission under Article 260 of the Treaty on the Functioning
of the European Union (TFEU).
dummy. A dummy variable indicating whether the
decision is the closing of the case by the Commission.
dummy. A dummy variable indicating whether
the decision is the withdrawal of the case by the Commission.
dummy. A dummy variable indicating whether
the decision is an additional decision (a decision of the same type as a
previous decision).
dummy. A dummy variable indicating whether the
Commission published a press release to publicize the decision.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.